==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/ro-RO/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Acest utilizator se poate conecta',
    'activated_disabled_help_text' => 'Nu puteți edita starea activării pentru propriul cont.',
    'assets_user'       => 'Activul desemnat catre :name',
    'bulk_update_warn'	=> 'Sunteți pe punctul de a edita proprietățile utilizatorilor: user_count. Rețineți că nu puteți modifica propriile atribute ale utilizatorilor utilizând acest formular și trebuie să efectuați modificări individuale ale propriului dvs. utilizator.',
    'bulk_update_help'	=> 'Acest formular vă permite să actualizați simultan mai mulți utilizatori. Completați câmpurile pe care trebuie să le schimbați. Toate câmpurile rămase necompletate vor rămâne neschimbate.',
    'current_assets'    => 'Activele licitate în prezent la acest utilizator',
    'clone'             => 'Cloneaza utilizator',
    'contact_user'      => 'Contact :name',
    'edit'              => 'Editeaza utilizator',
    'filetype_info'     => 'Tipurile de fișiere permise sunt png, gif, jpg, jpeg, doc, docx, pdf, txt, zip și rar.',
    'history_user'      => 'Istoric pentru :name',
    'info'				=> 'Info',
    'restore_user'		=> 'Faceți clic aici pentru a le restaura.',
    'last_login'        => 'Ultima logare',
    'ldap_config_text'  => 'Setările de configurare LDAP pot fi găsite pe Administrator> Setări. Locația selectată (opțional) va fi setată pentru toți utilizatorii importați.',
    'print_assigned'    => 'Tipărește toate activele atribuite',
    'email_assigned'    => 'Lista de e-mail a tuturor atribuite',
    'user_notified'     => 'Utilizatorul a primit prin e-mail o listă cu articolele alocate în prezent.',
    'auto_assign_label' => 'Include acest utilizator la atribuirea automată a licențelor eligibile',
    'auto_assign_help'  => 'Sari peste acest utilizator în atribuirea automată a licențelor',
    'software_user'     => 'Software predat catre :name',
    'send_email_help'   => 'Trebuie să furnizați o adresă de e-mail pentru ca acest utilizator să îi trimită acreditările. Trimiterea de acreditări poate fi efectuată numai la crearea utilizatorului. Parolele sunt stocate într-un singur fel și nu pot fi recuperate după ce au fost salvate.',
    'view_user'         => 'Vezi utilizator :name',
    'usercsv'           => 'Fișier CSV',
    'two_factor_admin_optin_help' => 'Setările dvs. actuale de administrare permit executarea selectivă a autentificării cu două factori.',
    'two_factor_enrolled' => 'Dispozitivul 2FA Înregistrat',
    'two_factor_active'   => '2FA Active',
    'user_deactivated'  => 'Utilizatorul nu se poate conecta',
    'user_activated'  => 'Utilizatorul se poate conecta',
    'activation_status_warning' => 'Nu schimba starea de activare',
    'group_memberships_helpblock' => 'Doar superadminii pot edita membrii grupului.',
    'superadmin_permission_warning' => 'Numai superadminii pot acorda acces la superadminul utilizatorului.',
    'admin_permission_warning' => 'Numai utilizatorii cu drepturi de administrator sau mai mari pot acorda acces de administrator de utilizator.',
    'remove_group_memberships' => 'Elimină membrii grupului',
    'warning_deletion_information' => 'Sunteți pe cale să verificați TOATE articolele din :count utilizator(i) listat(e) mai jos. Numele Super Administratorului sunt evidențiate cu roșu.',
    'update_user_assets_status' => 'Actualizați toate activele pentru acești utilizatori la această stare',
    'checkin_user_properties' => 'Bifează în toate proprietățile asociate cu acești utilizatori',
    'remote_label'   => 'Acesta este un utilizator extern',
    'remote'   => 'Distanta',
    'remote_help' => 'Acest lucru poate fi util dacă trebuie să filtrezi de la utilizatorii la distanță care nu intră niciodată sau rareori în locațiile tale fizice.',
    'not_remote_label' => 'Acesta nu este un utilizator extern',
    'vip_label' => 'Utilizator VIP',
    'vip_help' => 'Acest lucru poate fi util pentru a marca persoane importante din sfora dumneavoastră dacă doriţi să le gestionaţi în moduri speciale.',
    'create_user' => 'Creează un utilizator',
    'create_user_page_explanation' => 'Acestea sunt informaţiile de cont pe care le veţi utiliza pentru prima dată pentru a accesa site-ul.',
    'email_credentials' => 'Acreditări e-mail',
    'email_credentials_text' => 'Trimite-mi datele de autentificare la adresa de e-mail de mai sus',
    'next_save_user' => 'Următorul: Salvează Utilizatorul',
    'all_assigned_list_generation' => 'Generat pe:',
    'email_user_creds_on_create' => 'Trimite prin e-mail acest utilizator acreditările lor?',
];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/ro-RO/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Acest utilizator se poate conecta',
    'activated_disabled_help_text' => 'Nu puteți edita starea activării pentru propriul cont.',
    'assets_user'       => 'Activul desemnat catre :name',
    'bulk_update_warn'	=> 'Sunteți pe punctul de a edita proprietățile utilizatorilor: user_count. Rețineți că nu puteți modifica propriile atribute ale utilizatorilor utilizând acest formular și trebuie să efectuați modificări individuale ale propriului dvs. utilizator.',
    'bulk_update_help'	=> 'Acest formular vă permite să actualizați simultan mai mulți utilizatori. Completați câmpurile pe care trebuie să le schimbați. Toate câmpurile rămase necompletate vor rămâne neschimbate.',
    'current_assets'    => 'Activele licitate în prezent la acest utilizator',
    'clone'             => 'Cloneaza utilizator',
    'contact_user'      => 'Contact :name',
    'edit'              => 'Editeaza utilizator',
    'filetype_info'     => 'Tipurile de fișiere permise sunt png, gif, jpg, jpeg, doc, docx, pdf, txt, zip și rar.',
    'history_user'      => 'Istoric pentru :name',
    'info'				=> 'Info',
    'restore_user'		=> 'Faceți clic aici pentru a le restaura.',
    'last_login'        => 'Ultima logare',
    'ldap_config_text'  => 'Setările de configurare LDAP pot fi găsite pe Administrator> Setări. Locația selectată (opțional) va fi setată pentru toți utilizatorii importați.',
    'print_assigned'    => 'Tipărește toate activele atribuite',
    'email_assigned'    => 'Lista de e-mail a tuturor atribuite',
    'user_notified'     => 'Utilizatorul a primit prin e-mail o listă cu articolele alocate în prezent.',
    'users_notified'    => 'The user has been emailed a list of their currently assigned items.|:count users have been emailed a list of their currently assigned items.',
    'users_notified_warning' => ':count user has been emailed a list of their currently assigned items, however :no_email users did not have an email address so could not be emailed.|:count users have been emailed a list of their currently assigned items, however :no_email user(s) did not have an email address so could not be emailed.',
    'auto_assign_label' => 'Include acest utilizator la atribuirea automată a licențelor eligibile',
    'auto_assign_help'  => 'Sari peste acest utilizator în atribuirea automată a licențelor',
    'software_user'     => 'Software predat catre :name',
    'send_email_help'   => 'Trebuie să furnizați o adresă de e-mail pentru ca acest utilizator să îi trimită acreditările. Trimiterea de acreditări poate fi efectuată numai la crearea utilizatorului. Parolele sunt stocate într-un singur fel și nu pot fi recuperate după ce au fost salvate.',
    'view_user'         => 'Vezi utilizator :name',
    'usercsv'           => 'Fișier CSV',
    'two_factor_admin_optin_help' => 'Setările dvs. actuale de administrare permit executarea selectivă a autentificării cu două factori.',
    'two_factor_enrolled' => 'Dispozitivul 2FA Înregistrat',
    'two_factor_active'   => '2FA Active',
    'user_deactivated'  => 'Utilizatorul nu se poate conecta',
    'user_activated'  => 'Utilizatorul se poate conecta',
    'activation_status_warning' => 'Nu schimba starea de activare',
    'group_memberships_helpblock' => 'Doar superadminii pot edita membrii grupului.',
    'superadmin_permission_warning' => 'Numai superadminii pot acorda acces la superadminul utilizatorului.',
    'admin_permission_warning' => 'Numai utilizatorii cu drepturi de administrator sau mai mari pot acorda acces de administrator de utilizator.',
    'remove_group_memberships' => 'Elimină membrii grupului',
    'warning_deletion_information' => 'Sunteți pe cale să verificați TOATE articolele din :count utilizator(i) listat(e) mai jos. Numele Super Administratorului sunt evidențiate cu roșu.',
    'update_user_assets_status' => 'Actualizați toate activele pentru acești utilizatori la această stare',
    'checkin_user_properties' => 'Bifează în toate proprietățile asociate cu acești utilizatori',
    'remote_label'   => 'Acesta este un utilizator extern',
    'remote'   => 'Distanta',
    'remote_help' => 'Acest lucru poate fi util dacă trebuie să filtrezi de la utilizatorii la distanță care nu intră niciodată sau rareori în locațiile tale fizice.',
    'not_remote_label' => 'Acesta nu este un utilizator extern',
    'vip_label' => 'Utilizator VIP',
    'vip_help' => 'Acest lucru poate fi util pentru a marca persoane importante din sfora dumneavoastră dacă doriţi să le gestionaţi în moduri speciale.',
    'create_user' => 'Creează un utilizator',
    'create_user_page_explanation' => 'Acestea sunt informaţiile de cont pe care le veţi utiliza pentru prima dată pentru a accesa site-ul.',
    'email_credentials' => 'Acreditări e-mail',
    'email_credentials_text' => 'Trimite-mi datele de autentificare la adresa de e-mail de mai sus',
    'next_save_user' => 'Următorul: Salvează Utilizatorul',
    'all_assigned_list_generation' => 'Generat pe:',
    'email_user_creds_on_create' => 'Trimite prin e-mail acest utilizator acreditările lor?',
];
